@@ -1,4 +1,4 @@
-from finqual import Finqual as fq
+from .core import Finqual
 import polars as pl
 import pandas as pd
 from concurrent.futures import ThreadPoolExecutor, as_completed
@@ -24,9 +24,9 @@ class CCA:
 
     def __init__(self, ticker: str):
         self.ticker = ticker
-        self.fq_ticker = fq(ticker)
+        self.fq_ticker = Finqual(ticker)
         self.sector = self.fq_ticker.sector
-        self.sectors = self.fq_ticker.load_label("data/sector_mapping.parquet")
+        self.sectors = self.fq_ticker.load_label("sector_mapping.parquet")
 
     @weak_lru(maxsize=10)
     def get_c(self):
@@ -50,10 +50,10 @@ class CCA:
 
         print("No comparable companies found.")
 
-    def _get_ratios(self, year: int, method_name: str, quarter: int|None = None):
+    def _get_ratios(self, year: int, method_name: str, quarter: int | None = None):
 
-        def fetch_ratios(ticker: str, year_f: int, method_name_f: str, quarter_f: int|None):
-            fq_instance = fq(ticker)
+        def fetch_ratios(ticker: str, year_f: int, method_name_f: str, quarter_f: int | None):
+            fq_instance = Finqual(ticker)
             func = getattr(fq_instance, method_name_f)
             return func(year_f, quarter_f)
 
@@ -75,7 +75,7 @@ class CCA:
     def _get_ratios_period(self, start_year: int, end_year: int, method_name: str, quarter: bool = False):
 
         def fetch_ratios(ticker: str, start_year_f: int, end_year_f: int, method_name_f: str, quarter_f: bool):
-            fq_instance = fq(ticker)
+            fq_instance = Finqual(ticker)
             func = getattr(fq_instance, method_name_f)
             return func(start_year_f, end_year_f, quarter_f)
 
@@ -95,15 +95,15 @@ class CCA:
         return df
 
     @weak_lru(maxsize=10)
-    def profitability_ratios(self, year: int, quarter: int|None = None):
+    def profitability_ratios(self, year: int, quarter: int | None = None):
         return self._get_ratios(year, 'profitability_ratios', quarter)
 
     @weak_lru(maxsize=10)
-    def liquidity_ratios(self, year: int, quarter: int|None = None):
+    def liquidity_ratios(self, year: int, quarter: int | None = None):
         return self._get_ratios(year, 'liquidity_ratios', quarter)
 
     @weak_lru(maxsize=10)
-    def valuation_ratios(self, year: int, quarter: int|None = None):
+    def valuation_ratios(self, year: int, quarter: int | None = None):
         return self._get_ratios(year, 'valuation_ratios', quarter)
 
     @weak_lru(maxsize=10)
@@ -117,4 +117,3 @@ class CCA:
     @weak_lru(maxsize=10)
     def valuation_ratios_period(self, start_year: int, end_year: int, quarter: bool = False):
         return self._get_ratios_period(start_year, end_year, 'valuation_ratios_period', quarter)
-
